import React from 'react'
import Badge from '../components/Badge'
import Title from '../components/Title'
import Accordion from '../components/Accordion'

const data = [
    {
        question: 'Our Mission',
        answer: "At Massa Al-Iraq Ltd., our mission is clear: to provide unparalleled services and support to our clients in the oil and gas sector. With a commitment to excellence, safety, and innovation, we strive to exceed expectations and foster long-term partnerships. By contributing positively to the success of our clients' projects, we aim to solidify our position as a trusted industry leader.",
    },
    {
        question: 'Our Vision',
        answer: "Our vision at Massa Al-Iraq Ltd. is to be the premier provider of oil and gas solutions, renowned for our unwavering dedication to quality, safety, and innovation. We envision ourselves as the go-to partner for clients seeking tailored, reliable, and sustainable solutions that drive success in their projects and operations.",
    },
    {
        question: 'The Purpose of the Company',
        answer: "Massa Al-Iraq Ltd. is dedicated to investing capital in the field of oil and gas services, offering a comprehensive range of solutions to meet industry needs. From importing and equipping drilling equipment to providing maintenance services and supplying materials, our purpose is to support the efficient and effective operation of oil and gas facilities.",
    },
    {
        question: 'Nature of the Work',
        answer: "Our work at Massa Al-Iraq Ltd. encompasses a broad spectrum of services related to the oil and gas industry. From importing, equipping, and operating drilling equipment to fabricating pipelines and constructing storage tanks, we specialize in delivering high-quality solutions tailored to our clients' needs. With expertise in mechanical works, electricity sector services, and lab preparation, we are equipped to handle diverse projects and ensure their success.",
    },
];

const about = () => {
    return (
        <div className='pt-4 pb-12 md:py-16 px-3 sm:px-12 2xl:px-[12%] flex flex-col gap-10'>
            <div className="relative about-image bg-img bg-[url('/about-image.png')] h-[40vh] md:h-[45vh] rounded-3xl flex flex-col md:gap-2 items-end justify-end pb-5 text-center font-semibold text-xl sm:text-3xl md:text-4xl lg:text-5xl ">
                <p className='w-full z-10'>Hello and Welcome to</p>
                <p className='w-full z-10 text-orange-500'>Massa Al-Iraq Ltd.</p>
            </div>

            <section>
                {/* Title */}
                <div className="flex flex-col items-center justify-center gap-6 md:items-end my-8 md:my-12">
                    <div className="w-full flex flex-col gap-2 xl:gap-4 items-center justify-center md:items-start">
                        <Badge label="WHO WE ARE" />
                        <Title label="About Our Company" />
                    </div>
                </div>

                <p className='font-medium text-xl leading-relaxed'>
                    Welcome to Massa Al-Iraq Ltd.! With a strong foothold in the oil and gas industry, we pride ourselves on delivering a diverse range of specialized services tailored to meet the unique demands of our clients. Our unwavering commitment to excellence, safety, and innovation fuels our mission to surpass expectations and forge enduring partnerships. With a wealth of experience spanning exploration, production, engineering, construction, maintenance, and environmental compliance, our dedicated team stands ready to tackle even the most complex challenges and deliver exceptional results.
                </p>
            </section>

            <section>
                {/* Title */}
                <div className="flex flex-col items-center justify-center gap-6 md:items-end my-8 md:my-12">
                    <div className="w-full flex flex-col gap-2 xl:gap-4 items-center justify-center">
                        <Badge label="Overview" />
                        <Title label="Our Company's Purpose and Scope" />
                    </div>
                </div>

                <div className='flex flex-col gap-3 items-center justify-center'>
                    <Accordion data={data} />
                </div>
            </section>
        </div>
    )
}

export default about